@@ -12,22 +12,22 @@ build_time_vars = {'ABIFLAGS': 'm',
  'AST_C_DIR': 'Python',
  'AST_H': 'Include/Python-ast.h',
  'AST_H_DIR': 'Include',
- 'BASECFLAGS': '-fno-strict-aliasing',
+ 'BASECFLAGS': '-fno-strict-aliasing -Wsign-compare -Wunreachable-code -mieee',
  'BASECPPFLAGS': '',
  'BASEMODLIBS': '',
  'BINDIR': '/usr/local/bin',
- 'BINLIBDEST': '/usr/local/lib/python3.4',
- 'BLDLIBRARY': '-L. -lpython3.4m',
+ 'BINLIBDEST': '/usr/local/lib/python3.5',
+ 'BLDLIBRARY': '-L. -lpython3.5m',
  'BLDSHARED': 'cc -pthread -shared -fPIC -L/usr/local/lib/ '
-              '-L/usr/obj/ports/Python-3.4.5/Python-3.4.5',
+              '-L/usr/obj/ports/Python-3.5.1/Python-3.5.1',
  'BUILDEXE': '',
  'BUILDPYTHON': 'python',
- 'BUILD_GNU_TYPE': 'x86_64-unknown-openbsd6.1',
+ 'BUILD_GNU_TYPE': 'alpha-unknown-openbsd5.9',
  'BYTESTR_DEPS': '\\',
  'CC': 'cc -pthread',
  'CCSHARED': '-fPIC',
- 'CFLAGS': '-fno-strict-aliasing -DNDEBUG -O2 -pipe   -fPIC -O2 -pipe -O2 '
-           '-pipe',
+ 'CFLAGS': '-fno-strict-aliasing -Wsign-compare -Wunreachable-code -mieee '
+           '-DNDEBUG -O2 -pipe   -fPIC -O2 -pipe -O2 -pipe',
  'CFLAGSFORSHARED': '-fPIC',
  'CFLAGS_NODIST': '',
  'CONFIGFILES': 'configure configure.ac acconfig.h pyconfig.h.in '
@@ -37,28 +37,28 @@ build_time_vars = {'ABIFLAGS': 'm',
  'CONFIGURE_CPPFLAGS': '-I/usr/local/include',
  'CONFIGURE_LDFLAGS': '-L/usr/local/lib/',
  'CONFIG_ARGS': "'--with-ensurepip=no' '--enable-shared' "
-                "'--srcdir=/usr/obj/ports/Python-3.4.5/Python-3.4.5' "
+                "'--srcdir=/usr/obj/ports/Python-3.5.1/Python-3.5.1' "
                 "'--with-fpectl' '--with-threads' '--enable-ipv6' "
-                "'--with-system-expat' '--with-system-ffi' "
+                "'--with-cxx_main' '--with-system-expat' '--with-system-ffi' "
                 "'--prefix=/usr/local' '--sysconfdir=/etc' "
                 "'--mandir=/usr/local/man' '--infodir=/usr/local/info' "
                 "'--localstatedir=/var' '--disable-silent-rules' "
                 "'--disable-gtk-doc' 'CC=cc' 'CFLAGS=-O2 -pipe' "
                 "'LDFLAGS=-L/usr/local/lib/' 'CPPFLAGS=-I/usr/local/include'",
  'CONFINCLUDEDIR': '/usr/local/include',
- 'CONFINCLUDEPY': '/usr/local/include/python3.4m',
- 'COREPYTHONPATH': ':plat-openbsd6',
- 'COVERAGE_INFO': '/usr/obj/ports/Python-3.4.5/Python-3.4.5/coverage.info',
- 'COVERAGE_REPORT': '/usr/obj/ports/Python-3.4.5/Python-3.4.5/lcov-report',
+ 'CONFINCLUDEPY': '/usr/local/include/python3.5m',
+ 'COREPYTHONPATH': ':plat-openbsd5',
+ 'COVERAGE_INFO': '/usr/obj/ports/Python-3.5.1/Python-3.5.1/coverage.info',
+ 'COVERAGE_REPORT': '/usr/obj/ports/Python-3.5.1/Python-3.5.1/lcov-report',
  'COVERAGE_REPORT_OPTIONS': '--no-branch-coverage --title "CPython lcov '
                             'report"',
  'CPPFLAGS': '-I. -IInclude -I./Include -I/usr/local/include',
  'CXX': 'c++ -pthread',
- 'DESTDIRS': '/usr/local /usr/local/lib /usr/local/lib/python3.4 '
-             '/usr/local/lib/python3.4/lib-dynload',
- 'DESTLIB': '/usr/local/lib/python3.4',
+ 'DESTDIRS': '/usr/local /usr/local/lib /usr/local/lib/python3.5 '
+             '/usr/local/lib/python3.5/lib-dynload',
+ 'DESTLIB': '/usr/local/lib/python3.5',
  'DESTPATH': '',
- 'DESTSHARED': '/usr/local/lib/python3.4/lib-dynload',
+ 'DESTSHARED': '/usr/local/lib/python3.5/lib-dynload',
  'DIRMODE': 755,
  'DIST': 'README ChangeLog configure configure.ac acconfig.h pyconfig.h.in '
          'Makefile.pre.in Include Lib Misc Ext-dummy',
@@ -91,7 +91,7 @@ build_time_vars = {'ABIFLAGS': 'm',
  'HAVE_ACOSH': 1,
  'HAVE_ADDRINFO': 1,
  'HAVE_ALARM': 1,
- 'HAVE_ALIGNED_REQUIRED': 0,
+ 'HAVE_ALIGNED_REQUIRED': 1,
  'HAVE_ALLOCA_H': 0,
  'HAVE_ALTZONE': 0,
  'HAVE_ASINH': 1,
@@ -108,6 +108,7 @@ build_time_vars = {'ABIFLAGS': 'm',
  'HAVE_BROKEN_PTHREAD_SIGMASK': 0,
  'HAVE_BROKEN_SEM_GETVALUE': 0,
  'HAVE_BROKEN_UNSETENV': 0,
+ 'HAVE_BUILTIN_ATOMIC': 0,
  'HAVE_C99_BOOL': 1,
  'HAVE_CHFLAGS': 1,
  'HAVE_CHOWN': 1,
@@ -133,6 +134,7 @@ build_time_vars = {'ABIFLAGS': 'm',
  'HAVE_DEV_PTC': 0,
  'HAVE_DEV_PTMX': 0,
  'HAVE_DIRECT_H': 0,
+ 'HAVE_DIRENT_D_TYPE': 1,
  'HAVE_DIRENT_H': 1,
  'HAVE_DIRFD': 1,
  'HAVE_DLFCN_H': 1,
@@ -177,8 +179,9 @@ build_time_vars = {'ABIFLAGS': 'm',
  'HAVE_FUTIMESAT': 0,
  'HAVE_GAI_STRERROR': 1,
  'HAVE_GAMMA': 1,
- 'HAVE_GCC_ASM_FOR_X64': 1,
- 'HAVE_GCC_ASM_FOR_X87': 1,
+ 'HAVE_GCC_ASM_FOR_MC68881': 0,
+ 'HAVE_GCC_ASM_FOR_X64': 0,
+ 'HAVE_GCC_ASM_FOR_X87': 0,
  'HAVE_GCC_UINT128_T': 1,
  'HAVE_GETADDRINFO': 1,
  'HAVE_GETC_UNLOCKED': 1,
@@ -201,6 +204,8 @@ build_time_vars = {'ABIFLAGS': 'm',
  'HAVE_GETPID': 1,
  'HAVE_GETPRIORITY': 1,
  'HAVE_GETPWENT': 1,
+ 'HAVE_GETRANDOM': 0,
+ 'HAVE_GETRANDOM_SYSCALL': 0,
  'HAVE_GETRESGID': 1,
  'HAVE_GETRESUID': 1,
  'HAVE_GETSID': 1,
@@ -244,6 +249,7 @@ build_time_vars = {'ABIFLAGS': 'm',
  'HAVE_LINKAT': 1,
  'HAVE_LINUX_CAN_BCM_H': 0,
  'HAVE_LINUX_CAN_H': 0,
+ 'HAVE_LINUX_CAN_RAW_FD_FRAMES': 0,
  'HAVE_LINUX_CAN_RAW_H': 0,
  'HAVE_LINUX_NETLINK_H': 0,
  'HAVE_LINUX_TIPC_H': 0,
@@ -302,6 +308,7 @@ build_time_vars = {'ABIFLAGS': 'm',
  'HAVE_READV': 1,
  'HAVE_REALPATH': 1,
  'HAVE_RENAMEAT': 1,
+ 'HAVE_RL_APPEND_HISTORY': 1,
  'HAVE_RL_CALLBACK': 1,
  'HAVE_RL_CATCH_SIGNAL': 1,
  'HAVE_RL_COMPLETION_APPEND_CHARACTER': 1,
@@ -361,6 +368,7 @@ build_time_vars = {'ABIFLAGS': 'm',
  'HAVE_STDARG_PROTOTYPES': 1,
  'HAVE_STDINT_H': 1,
  'HAVE_STDLIB_H': 1,
+ 'HAVE_STD_ATOMIC': 0,
  'HAVE_STRDUP': 1,
  'HAVE_STRFTIME': 1,
  'HAVE_STRINGS_H': 1,
@@ -457,55 +465,58 @@ build_time_vars = {'ABIFLAGS': 'm',
  'HGBRANCH': '',
  'HGTAG': '',
  'HGVERSION': '',
- 'HOST_GNU_TYPE': 'x86_64-unknown-openbsd6.1',
+ 'HOST_GNU_TYPE': 'alpha-unknown-openbsd5.9',
  'INCLDIRSTOMAKE': '/usr/local/include /usr/local/include '
-                   '/usr/local/include/python3.4m '
-                   '/usr/local/include/python3.4m',
+                   '/usr/local/include/python3.5m '
+                   '/usr/local/include/python3.5m',
  'INCLUDEDIR': '/usr/local/include',
- 'INCLUDEPY': '/usr/local/include/python3.4m',
- 'INSTALL': '/usr/obj/ports/Python-3.4.5/bin/install -c',
- 'INSTALL_DATA': '/usr/obj/ports/Python-3.4.5/bin/install -c  -m 644',
- 'INSTALL_PROGRAM': '/usr/obj/ports/Python-3.4.5/bin/install -c -s  -m 755',
- 'INSTALL_SCRIPT': '/usr/obj/ports/Python-3.4.5/bin/install -c  -m 755',
- 'INSTALL_SHARED': '/usr/obj/ports/Python-3.4.5/bin/install -c -m 555',
- 'INSTSONAME': 'libpython3.4m.so.1.0',
+ 'INCLUDEPY': '/usr/local/include/python3.5m',
+ 'INSTALL': '/usr/obj/ports/Python-3.5.1/bin/install -c',
+ 'INSTALL_DATA': '/usr/obj/ports/Python-3.5.1/bin/install -c  -m 644',
+ 'INSTALL_PROGRAM': '/usr/obj/ports/Python-3.5.1/bin/install -c -s  -m 755',
+ 'INSTALL_SCRIPT': '/usr/obj/ports/Python-3.5.1/bin/install -c  -m 755',
+ 'INSTALL_SHARED': '/usr/obj/ports/Python-3.5.1/bin/install -c -m 555',
+ 'INSTSONAME': 'libpython3.5m.so.0.0',
  'IO_H': 'Modules/_io/_iomodule.h',
  'IO_OBJS': '\\',
  'LDCXXSHARED': 'c++ -pthread -shared -fPIC',
- 'LDFLAGS': '-L/usr/local/lib/ -L/usr/obj/ports/Python-3.4.5/Python-3.4.5',
+ 'LDFLAGS': '-L/usr/local/lib/ -L/usr/obj/ports/Python-3.5.1/Python-3.5.1',
  'LDLAST': '',
- 'LDLIBRARY': 'libpython3.4m.so',
+ 'LDLIBRARY': 'libpython3.5m.so',
  'LDLIBRARYDIR': '',
  'LDSHARED': 'cc -pthread -shared -fPIC -L/usr/local/lib/ '
-             '-L/usr/obj/ports/Python-3.4.5/Python-3.4.5',
- 'LDVERSION': '3.4m',
+             '-L/usr/obj/ports/Python-3.5.1/Python-3.5.1',
+ 'LDVERSION': '3.5m',
  'LIBC': '',
- 'LIBDEST': '/usr/local/lib/python3.4',
+ 'LIBDEST': '/usr/local/lib/python3.5',
  'LIBDIR': '/usr/local/lib',
  'LIBFFI_INCLUDEDIR': '/usr/local/include',
  'LIBM': '-lm',
  'LIBOBJDIR': 'Python/',
  'LIBOBJS': '',
  'LIBPC': '/usr/local/lib/pkgconfig',
- 'LIBPL': '/usr/local/lib/python3.4/config-3.4m',
- 'LIBRARY': 'libpython3.4m.a',
+ 'LIBPL': '/usr/local/lib/python3.5/config-3.5m',
+ 'LIBRARY': 'libpython3.5m.a',
  'LIBRARY_OBJS': '\\',
  'LIBRARY_OBJS_OMIT_FROZEN': '\\',
  'LIBS': '-lintl -lpthread  -lutil',
  'LIBSUBDIRS': 'tkinter tkinter/test tkinter/test/test_tkinter \\',
- 'LINKCC': 'cc -pthread',
+ 'LINKCC': 'c++ -pthread',
  'LINKFORSHARED': '-Wl,--export-dynamic',
  'LIPO_32BIT_FLAGS': '',
+ 'LLVM_PROF_ERR': 'no',
+ 'LLVM_PROF_FILE': '',
+ 'LLVM_PROF_MERGER': '',
  'LN': 'ln',
  'LOCALMODLIBS': '',
  'LOG1P_DROPS_ZERO_SIGN': 0,
- 'MACHDEP': 'openbsd6',
- 'MACHDEPPATH': ':plat-openbsd6',
- 'MACHDEPS': 'plat-openbsd6',
+ 'MACHDEP': 'openbsd5',
+ 'MACHDEPPATH': ':plat-openbsd5',
+ 'MACHDEPS': 'plat-openbsd5',
  'MACHDEP_OBJS': '',
- 'MACHDESTLIB': '/usr/local/lib/python3.4',
+ 'MACHDESTLIB': '/usr/local/lib/python3.5',
  'MACOSX_DEPLOYMENT_TARGET': '',
- 'MAINCC': 'cc -pthread',
+ 'MAINCC': 'c++ -pthread',
  'MAJOR_IN_MKDEV': 0,
  'MAJOR_IN_SYSMACROS': 0,
  'MAKESETUP': './Modules/makesetup',
@@ -518,10 +529,10 @@ build_time_vars = {'ABIFLAGS': 'm',
             'Modules/_weakref.o  Modules/_functoolsmodule.o  '
             'Modules/_operator.o  Modules/_collectionsmodule.o  '
             'Modules/itertoolsmodule.o  Modules/atexitmodule.o  '
-            'Modules/_stat.o  Modules/_localemodule.o  Modules/_iomodule.o '
-            'Modules/iobase.o Modules/fileio.o Modules/bytesio.o '
-            'Modules/bufferedio.o Modules/textio.o Modules/stringio.o  '
-            'Modules/zipimport.o  Modules/faulthandler.o  '
+            'Modules/_stat.o  Modules/timemodule.o  Modules/_localemodule.o  '
+            'Modules/_iomodule.o Modules/iobase.o Modules/fileio.o '
+            'Modules/bytesio.o Modules/bufferedio.o Modules/textio.o '
+            'Modules/stringio.o  Modules/zipimport.o  Modules/faulthandler.o  '
             'Modules/_tracemalloc.o Modules/hashtable.o  '
             'Modules/symtablemodule.o  Modules/xxsubtype.o',
  'MODULE_OBJS': '\\',
@@ -532,6 +543,13 @@ build_time_vars = {'ABIFLAGS': 'm',
  'OPCODETARGETGEN': '\\',
  'OPCODETARGETGEN_FILES': '\\',
  'OPCODETARGETS_H': '\\',
+ 'OPCODE_H': './Include/opcode.h',
+ 'OPCODE_H_DIR': './Include',
+ 'OPCODE_H_GEN': '@echo python: not-found! cannot run '
+                 'Tools/scripts/generate_opcode_h.py  '
+                 './Tools/scripts/generate_opcode_h.py ./Lib/opcode.py '
+                 './Include/opcode.h',
+ 'OPCODE_H_SCRIPT': './Tools/scripts/generate_opcode_h.py',
  'OPT': '-DNDEBUG -O2 -pipe   -fPIC',
  'OTHER_LIBTOOL_OPT': '',
  'PACKAGE_BUGREPORT': 0,
@@ -546,11 +564,13 @@ build_time_vars = {'ABIFLAGS': 'm',
  'PGENOBJS': '\\ \\',
  'PGENSRCS': '\\ \\',
  'PGOBJS': '\\',
+ 'PGO_PROF_GEN_FLAG': '',
+ 'PGO_PROF_USE_FLAG': '',
  'PGSRCS': '\\',
- 'PLATDIR': 'plat-openbsd6',
+ 'PLATDIR': 'plat-openbsd5',
  'POBJS': '\\',
  'POSIX_SEMAPHORES_NOT_ENABLED': 0,
- 'PROFILE_TASK': './Tools/pybench/pybench.py -n 2 --with-gc --with-syscheck',
+ 'PROFILE_TASK': '-m test.regrtest --pgo',
  'PSRCS': '\\',
  'PTHREAD_SYSTEM_SCHED_SUPPORTED': 1,
  'PURIFY': '',
@@ -561,21 +581,21 @@ build_time_vars = {'ABIFLAGS': 'm',
  'PYTHONFRAMEWORKDIR': 'no-framework',
  'PYTHONFRAMEWORKINSTALLDIR': '',
  'PYTHONFRAMEWORKPREFIX': '',
- 'PYTHONPATH': ':plat-openbsd6',
+ 'PYTHONPATH': ':plat-openbsd5',
  'PYTHON_FOR_BUILD': './python -E',
  'PYTHON_HEADERS': '\\',
  'PYTHON_OBJS': '\\',
- 'PY_CFLAGS': '-fno-strict-aliasing -DNDEBUG -O2 -pipe   -fPIC -O2 -pipe -O2 '
-              '-pipe',
+ 'PY_CFLAGS': '-fno-strict-aliasing -Wsign-compare -Wunreachable-code -mieee '
+              '-DNDEBUG -O2 -pipe   -fPIC -O2 -pipe -O2 -pipe',
  'PY_CFLAGS_NODIST': '-Werror=declaration-after-statement',
- 'PY_CORE_CFLAGS': '-fno-strict-aliasing -DNDEBUG -O2 -pipe   -fPIC -O2 '
-                   '-pipe -O2 -pipe -Werror=declaration-after-statement -I. '
-                   '-IInclude -I./Include -I/usr/local/include -fPIC '
-                   '-DPy_BUILD_CORE',
+ 'PY_CORE_CFLAGS': '-fno-strict-aliasing -Wsign-compare -Wunreachable-code '
+                   '-mieee -DNDEBUG -O2 -pipe   -fPIC -O2 -pipe -O2 -pipe '
+                   '-Werror=declaration-after-statement -I. -IInclude '
+                   '-I./Include -I/usr/local/include -fPIC -DPy_BUILD_CORE',
  'PY_CPPFLAGS': '-I. -IInclude -I./Include -I/usr/local/include',
  'PY_FORMAT_LONG_LONG': '"ll"',
  'PY_FORMAT_SIZE_T': '"z"',
- 'PY_LDFLAGS': '-L/usr/local/lib/ -L/usr/obj/ports/Python-3.4.5/Python-3.4.5',
+ 'PY_LDFLAGS': '-L/usr/local/lib/ -L/usr/obj/ports/Python-3.5.1/Python-3.5.1',
  'Py_DEBUG': 0,
  'Py_ENABLE_SHARED': 1,
  'Py_HASH_ALGORITHM': 0,
@@ -584,7 +604,7 @@ build_time_vars = {'ABIFLAGS': 'm',
  'READELF': 'readelf',
  'RESSRCDIR': 'Mac/Resources/framework',
  'RETSIGTYPE': 'void',
- 'RUNSHARED': 'LD_LIBRARY_PATH=/usr/obj/ports/Python-3.4.5/Python-3.4.5',
+ 'RUNSHARED': 'LD_LIBRARY_PATH=/usr/obj/ports/Python-3.5.1/Python-3.5.1',
  'SCRIPTDIR': '/usr/local/lib',
  'SETPGRP_HAVE_ARG': 1,
  'SGI_ABI': '',
@@ -599,7 +619,7 @@ build_time_vars = {'ABIFLAGS': 'm',
  'SIZEOF_FPOS_T': 8,
  'SIZEOF_INT': 4,
  'SIZEOF_LONG': 8,
- 'SIZEOF_LONG_DOUBLE': 16,
+ 'SIZEOF_LONG_DOUBLE': 8,
  'SIZEOF_LONG_LONG': 8,
  'SIZEOF_OFF_T': 8,
  'SIZEOF_PID_T': 4,
@@ -611,8 +631,8 @@ build_time_vars = {'ABIFLAGS': 'm',
  'SIZEOF_VOID_P': 8,
  'SIZEOF_WCHAR_T': 4,
  'SIZEOF__BOOL': 1,
- 'SOABI': 'cpython-34m',
- 'SRCDIRS': 'Parser Grammar Objects Python Modules Mac',
+ 'SOABI': 'cpython-35m',
+ 'SRCDIRS': 'Parser Grammar Objects Python Modules Mac Programs',
  'SRC_GDB_HOOKS': './Tools/gdb/libpython.py',
  'STDC_HEADERS': 1,
  'STRICT_SYSV_CURSES': "/* Don't use ncurses extensions */",
@@ -626,10 +646,10 @@ build_time_vars = {'ABIFLAGS': 'm',
  'TCLTK_LIBS': '',
  'TESTOPTS': '',
  'TESTPATH': '',
- 'TESTPYTHON': 'LD_LIBRARY_PATH=/usr/obj/ports/Python-3.4.5/Python-3.4.5 '
+ 'TESTPYTHON': 'LD_LIBRARY_PATH=/usr/obj/ports/Python-3.5.1/Python-3.5.1 '
                './python',
  'TESTPYTHONOPTS': '',
- 'TESTRUNNER': 'LD_LIBRARY_PATH=/usr/obj/ports/Python-3.4.5/Python-3.4.5 '
+ 'TESTRUNNER': 'LD_LIBRARY_PATH=/usr/obj/ports/Python-3.5.1/Python-3.5.1 '
                './python ./Tools/scripts/run_tests.py',
  'TESTTIMEOUT': 3600,
  'THREADOBJ': 'Python/thread.o',
@@ -640,8 +660,8 @@ build_time_vars = {'ABIFLAGS': 'm',
  'UNIVERSALSDK': '',
  'USE_COMPUTED_GOTOS': 0,
  'USE_INLINE': 1,
- 'VA_LIST_IS_ARRAY': 1,
- 'VERSION': '3.4',
+ 'VA_LIST_IS_ARRAY': 0,
+ 'VERSION': '3.5',
  'WANT_SIGFPE_HANDLER': 1,
  'WINDOW_HAS_FLAGS': 1,
  'WITH_DOC_STRINGS': 1,
@@ -654,8 +674,8 @@ build_time_vars = {'ABIFLAGS': 'm',
  'WITH_VALGRIND': 0,
  'X87_DOUBLE_ROUNDING': 0,
  'XMLLIBSUBDIRS': 'xml xml/dom xml/etree xml/parsers xml/sax',
- 'abs_builddir': '/usr/obj/ports/Python-3.4.5/Python-3.4.5',
- 'abs_srcdir': '/usr/obj/ports/Python-3.4.5/Python-3.4.5',
+ 'abs_builddir': '/usr/obj/ports/Python-3.5.1/Python-3.5.1',
+ 'abs_srcdir': '/usr/obj/ports/Python-3.5.1/Python-3.5.1',
  'datarootdir': '/usr/local/share',
  'exec_prefix': '/usr/local',
  'prefix': '/usr/local',
